@@ -1,9 +1,10 @@
 package Parallel::ForkManager::Segmented;
-$Parallel::ForkManager::Segmented::VERSION = '0.8.0';
+$Parallel::ForkManager::Segmented::VERSION = '0.10.0';
 use strict;
 use warnings;
 use 5.014;
 
+use Parallel::ForkManager::Segmented::Base v0.4.0 ();
 use parent 'Parallel::ForkManager::Segmented::Base';
 
 use Parallel::ForkManager ();
@@ -17,12 +18,11 @@ sub run
     my ( $WITH_PM, $batch_cb, $batch_size, $nproc, $stream_cb, ) =
         @{$processed}{qw/ WITH_PM batch_cb batch_size nproc stream_cb  /};
 
+    return $self->serial_run($processed) if not $WITH_PM;
+
     my $pm;
 
-    if ($WITH_PM)
-    {
-        $pm = Parallel::ForkManager->new($nproc);
-    }
+    $pm = Parallel::ForkManager->new($nproc);
     my $batch = $stream_cb->( { size => 1 } )->{items};
     return if not defined $batch;
     $batch_cb->($batch);
@@ -30,25 +30,16 @@ ITEMS:
     while (
         defined( $batch = $stream_cb->( { size => $batch_size } )->{items} ) )
     {
-        if ($WITH_PM)
-        {
-            my $pid = $pm->start;
+        my $pid = $pm->start;
 
-            if ($pid)
-            {
-                next ITEMS;
-            }
+        if ($pid)
+        {
+            next ITEMS;
         }
         $batch_cb->($batch);
-        if ($WITH_PM)
-        {
-            $pm->finish;    # Terminates the child process
-        }
-    }
-    if ($WITH_PM)
-    {
-        $pm->wait_all_children;
+        $pm->finish;    # Terminates the child process
     }
+    $pm->wait_all_children;
     return;
 }
 
@@ -67,7 +58,7 @@ segments of items.
 
 =head1 VERSION
 
-version 0.8.0
+version 0.10.0
 
 =head1 SYNOPSIS
 
